==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDataCloneStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDataCloneStrategyDescription } from "./WebDataCloneStrategyDescription";
/**
 * @hidden
 */
var WebDataCloneStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDataCloneStrategyDescriptionMetadata, _super);
    function WebDataCloneStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDataCloneStrategyDescriptionMetadata.b = function (a) {
        if (WebDataCloneStrategyDescriptionMetadata.a == null) {
            WebDataCloneStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDataCloneStrategyDescriptionMetadata.c(WebDataCloneStrategyDescriptionMetadata.a);
        }
        if (a.j(WebDataCloneStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDataCloneStrategyDescriptionMetadata.a);
    };
    WebDataCloneStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DataCloneStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebDataCloneStrategyDescriptionMetadata.d = function (a) {
        WebDataCloneStrategyDescriptionMetadata.b(a);
        a.aa("WebDataCloneStrategy", function () { return new WebDataCloneStrategyDescription(); });
        a.z("WebDataCloneStrategy", WebDataCloneStrategyDescriptionMetadata.a);
    };
    WebDataCloneStrategyDescriptionMetadata.$t = markType(WebDataCloneStrategyDescriptionMetadata, 'WebDataCloneStrategyDescriptionMetadata');
    WebDataCloneStrategyDescriptionMetadata.a = null;
    return WebDataCloneStrategyDescriptionMetadata;
}(Base));
export { WebDataCloneStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebDataCloneStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDataCloneStrategyDescription } from "./WebDataCloneStrategyDescription";
/**
 * @hidden
 */
var WebDataCloneStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDataCloneStrategyDescriptionMetadata, _super);
    function WebDataCloneStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDataCloneStrategyDescriptionMetadata.b = function (a) {
        if (WebDataCloneStrategyDescriptionMetadata.a == null) {
            WebDataCloneStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDataCloneStrategyDescriptionMetadata.c(WebDataCloneStrategyDescriptionMetadata.a);
        }
        if (a.k(WebDataCloneStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebDataCloneStrategyDescriptionMetadata.a);
    };
    WebDataCloneStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DataCloneStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebDataCloneStrategyDescriptionMetadata.d = function (a) {
        WebDataCloneStrategyDescriptionMetadata.b(a);
        a.ac("WebDataCloneStrategy", function () { return new WebDataCloneStrategyDescription(); });
        a.ab("WebDataCloneStrategy", WebDataCloneStrategyDescriptionMetadata.a);
    };
    WebDataCloneStrategyDescriptionMetadata.$t = markType(WebDataCloneStrategyDescriptionMetadata, 'WebDataCloneStrategyDescriptionMetadata');
    WebDataCloneStrategyDescriptionMetadata.a = null;
    return WebDataCloneStrategyDescriptionMetadata;
}(Base));
export { WebDataCloneStrategyDescriptionMetadata };
